@@ -1,6 +1,7 @@
 import re
 import os
-from astroid import MANAGER, CallFunc, Name, Assign, Keyword, List, Tuple, Const
+from astroid.builder import AstroidBuilder
+from astroid import MANAGER, CallFunc, Name, Assign, Keyword, List, Tuple, Const, AssName
 from requirements_detector.requirement import DetectedRequirement
 
 
@@ -94,7 +95,8 @@ class SetupWalker(object):
         for child_node in node.get_children():
             if top and isinstance(child_node, Assign):
                 for target in child_node.targets:
-                    self._top_level_assigns[target.name] = child_node.value
+                    if isinstance(target, AssName):
+                        self._top_level_assigns[target.name] = child_node.value
             self.walk(child_node)
 
     def _get_list_value(self, list_node):
@@ -143,7 +145,9 @@ class SetupWalker(object):
 
 
 def from_setup_py(setup_file):
-    ast = MANAGER.ast_from_file(setup_file)
+    with open(setup_file) as f:
+        ast = AstroidBuilder(MANAGER).string_build(f.read())
+
     walker = SetupWalker(ast)
 
     requirements = []
